@@ -16,7 +16,7 @@
 
 #include "qqprotocol.h"
 #include <QList>
-#include <kgenericfactory.h>
+#include <kpluginfactory.h>
 #include <kdebug.h>
 
 #include "kopeteaccountmanager.h"
@@ -24,28 +24,29 @@
 #include "qqcontact.h"
 #include "qqaddcontactpage.h"
 #include "ui/qqeditaccountwidget.h"
+#include <KLocalizedString>
 
 K_PLUGIN_FACTORY( QQProtocolFactory, registerPlugin<QQProtocol>(); )
 K_EXPORT_PLUGIN( QQProtocolFactory( "kopete_qq" ) )
 
-QQProtocol *QQProtocol::s_protocol = 0L;
+QQProtocol *QQProtocol::s_protocol = nullptr;
 
 QQProtocol::QQProtocol( QObject* parent, const QVariantList &/*args*/ )
-	: Kopete::Protocol( QQProtocolFactory::componentData(), parent ),
+    : Kopete::Protocol( parent ),
 	  qqOnline(  Kopete::OnlineStatus::Online, 25, this, 0,  QStringList(QString()),  
 			  i18n( "Online" ),   i18n( "O&nline" ) ),
-	  qqAway(  Kopete::OnlineStatus::Away, 25, this, 1, QStringList(QLatin1String("msn_away")),  
+	  qqAway(  Kopete::OnlineStatus::Away, 25, this, 1, QStringList(QStringLiteral("msn_away")),  
 			  i18n( "Away" ),   i18n( "&Away" ) ),
 	  qqOffline(  Kopete::OnlineStatus::Offline, 25, this, 2,  QStringList(QString()), 
 			  i18n( "Offline" ),   i18n( "O&ffline" ) ),
 	  propNickName(Kopete::Global::Properties::self()->nickName()),
 	  propFullName(Kopete::Global::Properties::self()->fullName()),
-	  propCountry("QQVCardCountry", i18n("Country"), QString(), Kopete::PropertyTmpl::PersistentProperty ), 
-	  propState("QQVCardState", i18n("State"), QString(), Kopete::PropertyTmpl::PersistentProperty ), 
-	  propCity("QQVCardCity", i18n("State"), QString(), Kopete::PropertyTmpl::PersistentProperty ),
-	  propStreet("QQVCardAddress", i18n("Home Address"), QString(), Kopete::PropertyTmpl::PersistentProperty ),
-	  propZipcode("QQVCardZipcode", i18n("Zipcode"), QString(), Kopete::PropertyTmpl::PersistentProperty ), 
-	  propAge("QQVCardAge", i18n("Age"), QString(), Kopete::PropertyTmpl::PersistentProperty ),
+	  propCountry(QStringLiteral("QQVCardCountry"), i18n("Country"), QString(), Kopete::PropertyTmpl::PersistentProperty ), 
+	  propState(QStringLiteral("QQVCardState"), i18n("State"), QString(), Kopete::PropertyTmpl::PersistentProperty ), 
+	  propCity(QStringLiteral("QQVCardCity"), i18n("State"), QString(), Kopete::PropertyTmpl::PersistentProperty ),
+	  propStreet(QStringLiteral("QQVCardAddress"), i18n("Home Address"), QString(), Kopete::PropertyTmpl::PersistentProperty ),
+	  propZipcode(QStringLiteral("QQVCardZipcode"), i18n("Zipcode"), QString(), Kopete::PropertyTmpl::PersistentProperty ), 
+	  propAge(QStringLiteral("QQVCardAge"), i18n("Age"), QString(), Kopete::PropertyTmpl::PersistentProperty ),
     propEmail(Kopete::Global::Properties::self()->emailAddress())
 {
 	kDebug( 14210 ) ;
@@ -60,10 +61,10 @@ Kopete::Contact *QQProtocol::deserializeContact(
 	Kopete::MetaContact *metaContact, const QMap<QString, QString> &serializedData,
 	const QMap<QString, QString> &/* addressBookData */)
 {
-	QString contactId = serializedData[ "contactId" ];
-	QString accountId = serializedData[ "accountId" ];
-	QString type = serializedData[ "contactType" ];
-	Kopete::Contact::NameType nameType = Kopete::Contact::nameTypeFromString(serializedData[ "preferredNameType" ]);
+	QString contactId = serializedData[ QStringLiteral("contactId") ];
+	QString accountId = serializedData[ QStringLiteral("accountId") ];
+	QString type = serializedData[ QStringLiteral("contactType") ];
+	Kopete::Contact::NameType nameType = Kopete::Contact::nameTypeFromString(serializedData[ QStringLiteral("preferredNameType") ]);
 /*
 	QQContact::QQContactType tbcType;
 	if ( type == QString::fromLatin1( "echo" ) )
