@@ -23,16 +23,16 @@
 #include <QDomDocument>
 #include <QtCore/QCryptographicHash>
 
-#include <kaction.h>
+#include <QAction>
 #include <kactionmenu.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kmenu.h>
+#include <QMenu>
 #include <kmessagebox.h>
 #include <knotification.h>
 #include <KCodecs>
 #include <KInputDialog>
-#include <KStandardDirs>
+
 #include <KToolInvocation>
 
 #include "kopetechatsessionmanager.h"
@@ -72,16 +72,16 @@ m_lastMainConnectionError(Callbacks::NoError)
     clientid += MSN::SIPInvitations;
     clientid += MSN::SupportMultiPacketMessaging;
 
-    m_openInboxAction = new KAction(KIcon("mail-folder-inbox"), i18n("Open Inbo&x..."), this);
+    m_openInboxAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-folder-inbox")), i18n("Open Inbo&x..."), this);
     QObject::connect(m_openInboxAction, SIGNAL(triggered(bool)), this, SLOT(slotOpenInbox()));
 
-    m_changeDNAction = new KAction(i18n("&Change Display Name..."), this);
+    m_changeDNAction = new QAction(i18n("&Change Display Name..."), this);
     QObject::connect(m_changeDNAction, SIGNAL(triggered(bool)), this, SLOT(slotChangePublicName()));
 
-//     m_startChatAction = new KAction(KIcon("mail-message-new"), i18n("&Start Chat..."), this);
+//     m_startChatAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-message-new")), i18n("&Start Chat..."), this);
 //     QObject::connect(m_startChatAction, SIGNAL(triggered(bool)), this, SLOT(slotStartChat()));
     
-    m_openStatusAction = new KAction(i18n("Open MS&N service status site..."), this);
+    m_openStatusAction = new QAction(i18n("Open MS&N service status site..."), this);
     QObject::connect(m_openStatusAction, SIGNAL(triggered(bool)), this, SLOT(slotOpenStatus()));
 
     tmpMailFile = 0L;
@@ -1055,7 +1055,6 @@ WlmAccount::connectionCompleted ()
     QObject::connect (&m_server->cb, SIGNAL(gotRemovedGroup(bool,QString)),
                       this, SLOT(gotRemovedGroup(bool,QString)) );
 
-
     QObject::connect (&m_server->cb, SIGNAL(gotAddedContactToAddressBook(bool,QString,QString,QString)),
                       this, SLOT(gotAddedContactToAddressBook(bool,QString,QString,QString)));
 
@@ -1377,7 +1376,6 @@ void WlmAccount::error( int /*errCode*/ )
     logOff( Kopete::Account::ConnectionReset );
 }
 
-
 void WlmAccount::logOff( Kopete::Account::DisconnectReason reason )
 {
     kDebug (14210) << k_funcinfo;
@@ -1547,4 +1545,3 @@ void WlmAccount::slotRemoveRecentDPRequests()
     m_recentDPRequests.pop_front();
 }
 
-#include "wlmaccount.moc"
