@@ -17,10 +17,8 @@
 #ifndef YAHOOWEBCAMDIALOG_H_
 #define YAHOOWEBCAMDIALOG_H_
 
-
 #include <kdialog.h>
 
-
 class QPixmap;
 class QLabel;
 class QWidget;
@@ -34,15 +32,15 @@ class YahooWebcamDialog : public KDialog
 {
 Q_OBJECT
 public:
-	explicit YahooWebcamDialog( const QString &, QWidget* parent = 0 );
+	explicit YahooWebcamDialog( const QString &, QWidget* parent = nullptr );
 	~YahooWebcamDialog();
 	
 	void setViewer( const QStringList & );
-public slots:
+public Q_SLOTS:
 	void newImage( const QPixmap &image );
 	void webcamClosed( int );
 	void webcamPaused();
-signals:
+Q_SIGNALS:
 	void closingWebcamDialog();
 	
 private:
