@@ -24,17 +24,15 @@
 #include <QList>
 
 #include <kconfig.h>
-#include <kdebug.h>
-#include <kinputdialog.h>
-#include <klocale.h>
+#include "yahoo_protocol_debug.h"
+#include <KLocalizedString>
 #include <kmessagebox.h>
-#include <kmenu.h>
+#include <QMenu>
 #include <ktemporaryfile.h>
 #include <kxmlguiwindow.h>
 #include <ktoolbar.h>
 #include <krun.h>
-#include <kiconloader.h>
-#include <kicon.h>
+#include <QIcon>
 
 #include "kopetecontactaction.h"
 #include "kopetemetacontact.h"
@@ -52,35 +50,36 @@ YahooChatSession::YahooChatSession( Kopete::Protocol *protocol, const Kopete::Co
 	Kopete::ContactPtrList others )
 : Kopete::ChatSession( user, others, protocol )
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+    setComponentName(QStringLiteral("yahoo_protocol"), i18n("Kopete"));
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	Kopete::ChatSessionManager::self()->registerChatSession( this );
-	setComponentData(protocol->componentData());
+    //
 
 	// Add Actions
-	KAction *buzzAction = new KAction( KIcon("bell"), i18n( "Buzz Contact" ), this );
-        actionCollection()->addAction( "yahooBuzz", buzzAction );
-	buzzAction->setShortcut( KShortcut("Ctrl+G") );
+    QAction *buzzAction = new QAction( QIcon::fromTheme(QStringLiteral("bell")), i18n( "Buzz Contact" ), this );
+        actionCollection()->addAction( QStringLiteral("yahooBuzz"), buzzAction );
+    buzzAction->setShortcut( QKeySequence(QStringLiteral("Ctrl+G")) );
 	connect( buzzAction, SIGNAL(triggered(bool)), this, SLOT(slotBuzzContact()) );
 
-	KAction *userInfoAction = new KAction( KIcon("help-about"), i18n( "Show User Info" ), this );
-        actionCollection()->addAction( "yahooShowInfo",  userInfoAction) ;
+    QAction *userInfoAction = new QAction( QIcon::fromTheme(QStringLiteral("help-about")), i18n( "Show User Info" ), this );
+        actionCollection()->addAction( QStringLiteral("yahooShowInfo"),  userInfoAction) ;
 	connect( userInfoAction, SIGNAL(triggered(bool)), this, SLOT(slotUserInfo()) );
 
-	KAction *receiveWebcamAction = new KAction( KIcon("webcamreceive"), i18n( "Request Webcam" ), this );
-        actionCollection()->addAction( "yahooRequestWebcam",  receiveWebcamAction) ;
+    QAction *receiveWebcamAction = new QAction( QIcon::fromTheme(QStringLiteral("webcamreceive")), i18n( "Request Webcam" ), this );
+        actionCollection()->addAction( QStringLiteral("yahooRequestWebcam"),  receiveWebcamAction) ;
 	connect( receiveWebcamAction, SIGNAL(triggered(bool)), this, SLOT(slotRequestWebcam()) );
 
-	KAction *sendWebcamAction = new KAction( KIcon("webcamsend"), i18n( "Invite to view your Webcam" ), this );
-        actionCollection()->addAction( "yahooSendWebcam",  sendWebcamAction) ;
+    QAction *sendWebcamAction = new QAction( QIcon::fromTheme(QStringLiteral("webcamsend")), i18n( "Invite to view your Webcam" ), this );
+        actionCollection()->addAction( QStringLiteral("yahooSendWebcam"),  sendWebcamAction) ;
 	connect( sendWebcamAction, SIGNAL(triggered(bool)), this, SLOT(slotInviteWebcam()) );
 
 	YahooContact *c = static_cast<YahooContact*>( others.first() );
 	connect( c, SIGNAL(displayPictureChanged()), this, SLOT(slotDisplayPictureChanged()) );
 	m_image = new QLabel( 0L );
-	m_image->setObjectName( QLatin1String("kde toolbar widget") );
-	KAction *imageAction = new KAction( i18n( "Yahoo Display Picture" ), this );
-        actionCollection()->addAction( "yahooDisplayPicture", imageAction );
-	imageAction->setDefaultWidget( m_image );
+	m_image->setObjectName( QStringLiteral("kde toolbar widget") );
+    QAction *imageAction = new QAction( i18n( "Yahoo Display Picture" ), this );
+        actionCollection()->addAction( QStringLiteral("yahooDisplayPicture"), imageAction );
+    //KF5 FIXME imageAction->setDefaultWidget( m_image );
 	connect( imageAction, SIGNAL(triggered()), this, SLOT(slotDisplayPictureChanged()) );
 
 	if(c->hasProperty(Kopete::Global::Properties::self()->photo().key())  )
@@ -89,10 +88,10 @@ YahooChatSession::YahooChatSession( Kopete::Protocol *protocol, const Kopete::Co
 	}
 	else
 	{
-		m_image = 0L;
+		m_image = nullptr;
 	}
 
-	setXMLFile("yahooimui.rc");
+	setXMLFile(QStringLiteral("yahooimui.rc"));
 }
 
 YahooChatSession::~YahooChatSession()
@@ -102,42 +101,42 @@ YahooChatSession::~YahooChatSession()
 
 void YahooChatSession::slotBuzzContact()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	QList<Kopete::Contact*>contacts = members();
 	static_cast<YahooContact *>(contacts.first())->buzzContact();
 }
 
 void YahooChatSession::slotUserInfo()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	QList<Kopete::Contact*>contacts = members();
 	static_cast<YahooContact *>(contacts.first())->slotUserInfo();
 }
 
 void YahooChatSession::slotRequestWebcam()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	QList<Kopete::Contact*>contacts = members();
 	static_cast<YahooContact *>(contacts.first())->requestWebcam();
 }
 
 void YahooChatSession::slotInviteWebcam()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	QList<Kopete::Contact*>contacts = members();
 	static_cast<YahooContact *>(contacts.first())->inviteWebcam();
 }
 
 void YahooChatSession::slotSendFile()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	QList<Kopete::Contact*>contacts = members();
 	static_cast<YahooContact *>(contacts.first())->sendFile();
 }
 
 void YahooChatSession::slotDisplayPictureChanged()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	QList<Kopete::Contact*> mb=members();
 	YahooContact *c = static_cast<YahooContact *>( mb.first() );
 	if ( c && m_image )
@@ -157,7 +156,7 @@ void YahooChatSession::slotDisplayPictureChanged()
 				//We connected that in the constructor.  we don't need to keep this slot active.
 				disconnect( Kopete::ChatSessionManager::self() , SIGNAL(viewActivated(KopeteView*)) , this, SLOT(slotDisplayPictureChanged()) );
 
-				KAction *imgAction=actionCollection()->action("yahooDisplayPicture");
+                QAction *imgAction=actionCollection()->action("yahooDisplayPicture");
 				if(imgAction)
 				{
 					QList<KToolBar*> toolbarList = w->toolBarList();
@@ -193,4 +192,3 @@ void YahooChatSession::slotDisplayPictureChanged()
 	}
 }
 
-#include "yahoochatsession.moc"
