@@ -42,18 +42,17 @@ private:
 	QString m_photoPath;
 
 public:
-	YahooEditAccount(YahooProtocol *protocol, Kopete::Account *theAccount, QWidget *parent = 0);
+	YahooEditAccount(YahooProtocol *protocol, Kopete::Account *theAccount, QWidget *parent = nullptr);
 
-	virtual bool validateData();
+	bool validateData() Q_DECL_OVERRIDE;
 
-public slots:
-	virtual Kopete::Account *apply();
+public Q_SLOTS:
+	Kopete::Account *apply() Q_DECL_OVERRIDE;
 
-private slots:
+private Q_SLOTS:
 	void slotOpenRegister();
 	void slotSelectPicture();
 };
 
 #endif // YAHOOEDITACCOUNT_H
 
-// vim: set noet ts=4 sts=4 sw=4:
